@@ -1,3 +1,5 @@
+use std::io;
+
 use super::{
     as_handle::AsHandle, diagnostics::Record as DiagnosticRecord, logging::log_diagnostics,
 };
@@ -18,10 +20,14 @@ pub enum Error {
     /// A user dialog to complete the connection string has been aborted.
     #[error("The dialog shown to provide or complete the connection string has been aborted.")]
     AbortedConnectionStringCompletion,
-    #[error("ODBC diver manager does not seem to support the required ODBC version 3.80. (Most
+    #[error(
+        "ODBC diver manager does not seem to support the required ODBC version 3.80. (Most
         likely you need to update unixODBC if you run on a Linux. Diagnostic record returned by
-        SQLSetEnvAttr:\n{0}")]
+        SQLSetEnvAttr:\n{0}"
+    )]
     OdbcApiVersionUnsupported(DiagnosticRecord),
+    #[error("Sending data to the database at statement execution time failed. IO error:\n{0}")]
+    FailedReadingInput(io::Error),
 }
 
 pub trait IntoResult {
